import * as i0 from '@angular/core';
import { Injectable, Component, ViewEncapsulation, ChangeDetectionStrategy, Optional, Inject, Input, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';

class BootstrapIconsRegistry {
    constructor() {
        this.registry = new Map();
    }
    registerIcons(icons) {
        icons.forEach((icon) => this.registry.set(icon.name, icon.data));
    }
    getIcon(iconName) {
        if (!this.registry.has(iconName)) {
            console.warn(`We could not find the dinosaur Icon with the name ${iconName}, did you add it to the Icon registry?`);
        }
        return this.registry.get(iconName);
    }
}
BootstrapIconsRegistry.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconsRegistry, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
BootstrapIconsRegistry.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconsRegistry, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconsRegistry, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class BootstrapIconComponent {
    constructor(element, iconsRegistry, document) {
        this.element = element;
        this.iconsRegistry = iconsRegistry;
        this.document = document;
    }
    set name(iconName) {
        if (this.svgIcon) {
            this.element.nativeElement.removeChild(this.svgIcon);
        }
        const svgData = this.iconsRegistry.getIcon(iconName);
        if (svgData) {
            this.svgIcon = this.svgElementFromString(svgData);
            this.element.nativeElement.appendChild(this.svgIcon);
        }
    }
    svgElementFromString(svgContent) {
        const div = this.document.createElement('DIV');
        if (div instanceof HTMLElement) {
            div.innerHTML = svgContent;
            return div.querySelector('svg') || this.document.createElementNS('http://www.w3.org/2000/svg', 'path');
        }
    }
}
BootstrapIconComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconComponent, deps: [{ token: i0.ElementRef }, { token: BootstrapIconsRegistry }, { token: DOCUMENT, optional: true }], target: i0.ɵɵFactoryTarget.Component });
BootstrapIconComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.2", type: BootstrapIconComponent, selector: "bootstrap-icon", inputs: { name: "name" }, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'bootstrap-icon',
                    template: `<ng-content></ng-content>`,
                    encapsulation: ViewEncapsulation.None,
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: BootstrapIconsRegistry }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; }, propDecorators: { name: [{
                type: Input
            }] } });

class BootstrapIconsModule {
    static forRoot() {
        return {
            ngModule: BootstrapIconsModule,
            providers: [
                BootstrapIconsRegistry,
            ],
        };
    }
}
BootstrapIconsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
BootstrapIconsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconsModule, declarations: [BootstrapIconComponent], exports: [BootstrapIconComponent] });
BootstrapIconsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconsModule, imports: [[]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: BootstrapIconsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [BootstrapIconComponent],
                    imports: [],
                    exports: [BootstrapIconComponent]
                }]
        }] });

/*
 * Public API Surface of the icons lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BootstrapIconComponent, BootstrapIconsModule, BootstrapIconsRegistry };
//# sourceMappingURL=triangular-bootstrap-icons.mjs.map
